@@ -4,6 +4,13 @@ from .datetime_util import DateTimeUtil
 from .object_util import ObjectUtil
 from .path_util import PathUtil
 from .string_util import StringUtil
+from .xml_util import XMLUtil
 
 
-__all__ = ['DateTimeUtil', 'ObjectUtil', 'PathUtil', 'StringUtil']
+__all__ = [
+    'DateTimeUtil',
+    'ObjectUtil',
+    'PathUtil',
+    'StringUtil',
+    'XMLUtil',
+]
